..
   This is an autogenerated file from processors.rst

avatars.processors.ToCategoricalProcessor
=========================================

.. autoclass:: avatars.processors.ToCategoricalProcessor
   :members: